@@ -2,13 +2,16 @@ from dataclasses import dataclass
 import datetime
 from typing import Optional
 
+
 @dataclass
 class VaccinationByDayRow:
     """Represents on row of vaccinations by day table"""
+
     date: datetime.datetime
     first_dose: int
     second_dose: int = 0
 
+
 @dataclass
 class VaccinationByAgeRow:
     age_group: str
@@ -17,12 +20,14 @@ class VaccinationByAgeRow:
     share_first: float
     share_second: float
 
+
 @dataclass
 class VaccineSupplyUsage:
     date: datetime.datetime
     supplied: int
     used: int
 
+
 @dataclass
 class VaccinationByRegionRow:
     region: str
@@ -31,10 +36,22 @@ class VaccinationByRegionRow:
     share_first: float
     share_second: float
 
+
 @dataclass
 class VaccinationByManufacturerRow:
     date: datetime.datetime
     pfizer: Optional[int]
     moderna: Optional[int]
     az: Optional[int]
-    
\ No newline at end of file
+
+
+@dataclass
+class VaccinationDose:
+    date: datetime.datetime
+    dose: int
+
+
+@dataclass
+class VaccinationByAgeRange:
+    dose1: "list[VaccinationDose]"
+    dose2: "list[VaccinationDose]"
